@@ -15,68 +15,20 @@
 # specific language governing permissions and limitations
 # under the License.
 
-require_relative 'logging'
 require_relative 'custom_cleanup'
-include Elasticsearch::RestAPIYAMLTests::Logging
 
 module Elasticsearch
   module RestAPIYAMLTests
     module WipeCluster
       PRESERVE_ILM_POLICY_IDS = [
-        'ilm-history-ilm-policy',
-        'slm-history-ilm-policy',
-        'watch-history-ilm-policy',
-        'watch-history-ilm-policy-16',
-        'ml-size-based-ilm-policy',
-        'logs',
-        'logs@lifecycle',
-        'metrics',
-        'metrics@lifecycle',
-        'profiling-60-days',
-        'profiling-60-days@lifecycle',
-        'synthetics',
-        'agentless',
-        'synthetics@lifecycle',
-        'traces@lifecycle',
-        '7-days-default',
-        '7-days@lifecycle',
-        '30-days-default',
-        '30-days@lifecycle',
-        '90-days-default',
-        '90-days@lifecycle',
-        '180-days-default',
-        '180-days@lifecycle',
-        '365-days-default',
-        '365-days@lifecycle',
-        '.fleet-files-ilm-policy',
-        '.fleet-file-data-ilm-policy',
-        '.fleet-actions-results-ilm-policy',
-        '.fleet-file-fromhost-data-ilm-policy',
-        '.fleet-file-fromhost-meta-ilm-policy',
-        '.fleet-file-tohost-data-ilm-policy',
-        '.fleet-file-tohost-meta-ilm-policy',
-        '.deprecation-indexing-ilm-policy',
-        '.monitoring-8-ilm-policy',
-        'behavioral_analytics-events-default_policy',
-        'logs-apm.app_logs-default_policy',
-        'logs-apm.error_logs-default_policy',
-        'metrics-apm.app_metrics-default_policy',
-        'metrics-apm.internal_metrics-default_policy',
-        'metrics-apm.service_destination_10m_metrics-default_policy',
-        'metrics-apm.service_destination_1m_metrics-default_policy',
-        'metrics-apm.service_destination_60m_metrics-default_policy',
-        'metrics-apm.service_summary_10m_metrics-default_policy',
-        'metrics-apm.service_summary_1m_metrics-default_policy',
-        'metrics-apm.service_summary_60m_metrics-default_policy',
-        'metrics-apm.service_transaction_10m_metrics-default_policy',
-        'metrics-apm.service_transaction_1m_metrics-default_policy',
-        'metrics-apm.service_transaction_60m_metrics-default_policy',
-        'metrics-apm.transaction_10m_metrics-default_policy',
-        'metrics-apm.transaction_1m_metrics-default_policy',
-        'metrics-apm.transaction_60m_metrics-default_policy',
-        'traces-apm.rum_traces-default_policy',
-        'traces-apm.sampled_traces-default_policy',
-        'traces-apm.traces-default_policy'
+        'ilm-history-ilm-policy', 'slm-history-ilm-policy', 'watch-history-ilm-policy',
+        'watch-history-ilm-policy-16', 'ml-size-based-ilm-policy', 'logs', 'metrics', 'profiling',
+        'synthetics', '7-days-default', '30-days-default', '90-days-default', '180-days-default',
+        '365-days-default', '.fleet-files-ilm-policy', '.fleet-file-data-ilm-policy',
+        '.fleet-actions-results-ilm-policy', '.fleet-file-fromhost-data-ilm-policy',
+        '.fleet-file-fromhost-meta-ilm-policy', '.fleet-file-tohost-data-ilm-policy',
+        '.fleet-file-tohost-meta-ilm-policy', '.deprecation-indexing-ilm-policy',
+        '.monitoring-8-ilm-policy', 'behavioral_analytics-events-default_policy'
       ].freeze
 
       PLATINUM_TEMPLATES = [
@@ -197,7 +149,7 @@ module Elasticsearch
           unexpected_ilm_policies = client.index_lifecycle_management.get_lifecycle
           unexpected_ilm_policies.reject! { |k, _| preserve_policy?(k) }
           unless unexpected_ilm_policies.empty?
-            logger.info(
+            client.logger.info(
               "Expected no ILM policies after deletions, but found #{unexpected_ilm_policies.keys.join(',')}"
             )
           end
@@ -212,7 +164,7 @@ module Elasticsearch
           unexpected_templates << legacy_templates.keys.reject { |t| platinum_template?(t) }
 
           unless unexpected_templates.reject(&:empty?).empty?
-            logger.info(
+            client.logger.info(
               "Expected no templates after deletions, but found #{unexpected_templates.join(',')}"
             )
           end
@@ -257,7 +209,7 @@ module Elasticsearch
             end
             break unless count.positive? && Time.now.to_i < (start_time + 1)
           end
-          logger.debug("Waited for #{count} pending rollup tasks for #{Time.now.to_i - start_time}s.") if count.positive?
+          client.logger.debug("Waited for #{count} pending rollup tasks for #{Time.now.to_i - start_time}s.") if count.positive?
         end
 
         def delete_all_slm_policies(client)
@@ -293,7 +245,7 @@ module Elasticsearch
                 response = client.snapshot.get(repository: repository, snapshot: '_all', ignore_unavailable: true)
                 response['snapshots'].each do |snapshot|
                   if snapshot['state'] != 'SUCCESS'
-                    logger.debug("Found snapshot that did not succeed #{snapshot}")
+                    client.logger.debug("Found snapshot that did not succeed #{snapshot}")
                   end
                   client.snapshot.delete(repository: repository, snapshot: snapshot['snapshot'], ignore: 404)
                 end
@@ -307,7 +259,7 @@ module Elasticsearch
           begin
             client.indices.delete_data_stream(name: '*', expand_wildcards: 'all')
           rescue StandardError => e
-            logger.error "Caught exception attempting to delete data streams: #{e}"
+            client.logger.error "Caught exception attempting to delete data streams: #{e}"
             client.indices.delete_data_stream(name: '*')
           end
         end
@@ -336,14 +288,13 @@ module Elasticsearch
           end
 
           # Always check for legacy templates
-          templates = client.indices.get_template
-          templates.each do |name, _|
+          client.indices.get_template.each_key do |name|
             next if platinum_template?(name)
 
             begin
               client.indices.delete_template(name: name)
             rescue StandardError => e
-              logger.info("Unable to remove index template #{name}")
+              client.logger.info("Unable to remove index template #{name} - #{e}")
             end
           end
         end
@@ -377,7 +328,6 @@ module Elasticsearch
             end
             break unless count.positive? && Time.now.to_i < (start_time + 5)
           end
-          logger.debug("Waited for #{count} pending cluster tasks for #{Time.now.to_i - start_time}s.") if count.positive?
         end
 
         def skippable_task?(task)
@@ -441,27 +391,24 @@ module Elasticsearch
         def clear_ml_jobs(client)
           client.ml.close_job(job_id: '_all', force: true)
           client.ml.get_jobs['jobs'].each do |d|
-            client.ml.delete_job(job_id: d['job_id'], wait_for_completion: false, force: true)
+            client.ml.delete_job(job_id: d['job_id'])
           end
         end
 
         def clear_datafeeds(client)
           client.ml.stop_datafeed(datafeed_id: '_all', force: true)
           client.ml.get_datafeeds['datafeeds'].each do |d|
-            Thread.new do
-              client.ml.stop_datafeed(datafeed_id: d['datafeed_id'], force: true)
-              client.ml.delete_datafeed(datafeed_id: d['datafeed_id'], force: true)
-            rescue StandardError
-              logger.info('Exception deleting datafeed')
-            end
+            client.ml.delete_datafeed(datafeed_id: d['datafeed_id'])
           end
         end
 
         def clear_tasks(client)
           tasks = client.tasks.get['nodes'].values.first['tasks'].values.select do |d|
             d['cancellable']
+          end.map do |d|
+            "#{d['node']}:#{d['id']}"
           end
-          tasks.each { |d| client.tasks.cancel(task_id: "#{d['node']}:#{d['id']}") }
+          tasks.each { |t| client.tasks.cancel task_id: t }
         end
 
         def clear_machine_learning_indices(client)
@@ -478,7 +425,7 @@ module Elasticsearch
 
         def clear_transforms(client)
           client.transform.get_transform(transform_id: '*')['transforms'].each do |transform|
-            client.transform.delete_transform(transform_id: transform['id'], force: true)
+            client.transform.delete_transform(transform_id: transform['id'])
           end
         end
 
@@ -490,11 +437,11 @@ module Elasticsearch
         end
 
         def delete_all_node_shutdown_metadata(client)
-          nodes = client.shutdown.get_node
-          return unless nodes['nodes']
+          nodes = client.perform_request(Elasticsearch::API::HTTP_GET, '_nodes/shutdown')
+          return unless nodes&.body['nodes'].any?
 
-          nodes['nodes'].each do |node|
-            client.shutdown.delete_node(node['node_id'])
+          nodes.body['nodes'].each do |node|
+            client.perform_request(Elasticsearch::API::HTTP_DELETE, "_nodes/#{node['node_id']}/shutdown")
           end
         end
 
@@ -512,7 +459,12 @@ module Elasticsearch
           return unless models['trained_model_configs']
 
           models['trained_model_configs'].each do |model|
-            client.ml.delete_trained_model(model_id: model['model_id'], force: true, ignore: 400)
+            client.ml.delete_trained_model(
+              model_id: model['model_id'],
+              force: true,
+              ignore: 400,
+              timeout: '10s'
+            )
           end
         end
       end
